==> includable-1.17.0.tgz: package/lib/commands/modules/deploy.js <==
/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

const FormData = require('form-data')
const fs = require('fs')
const chalk = require('chalk')

const API = require('../../util/API')
const output = require('../../output')
const runHelpers = require('../../run-helpers')
const Module = require('../../containers/Module')

const postRelease = function (moduleId, communityId) {
  const spinner = output.wait('Linking module to community')
  API.post('/communities/' + communityId + '/modules', { module: moduleId }).then(function () {
    spinner(true)
    output.newline()
    output.success('Done! Only thing left is to configure your DNS records:')
    output.write('\n' + chalk.bold.magenta('  CNAME inc-dns.com') + chalk.gray(' for any subdomains, or\n'))
    output.write(chalk.bold.magenta('  A 79.125.7.166') + chalk.gray(' if you can\'t add a CNAME record\n\n\n'))
  })
}

const deployWithCommunity = function (communityId) {
  Module.getManifest(function (manifest) {
    if (!('name' in manifest) || !manifest.name || typeof manifest.name !== 'string' || !manifest.name.length) {
      output.err('Please set a valid value for key `name` in module.json')
      return
    }

    runHelpers.startChildProcess('build', function (error, exitCode) {
      if (error || exitCode > 0) {
        output.err('Build script exited with non-zero exit code, cancelling publish action')
        return
      }
      runHelpers.createZipArchive('.', 'Publish', function (zipFile, size, unlinkFn) {
        const spinner = output.wait(runHelpers.logSyncMessage('Uploading module (' + size + ')', true))

        const data = new FormData(null)
        data.append('file', fs.createReadStream(zipFile))

        API.post('/modules/publish', data, { headers: data.getHeaders() }).then(function (response) {
          spinner()
          output.success('+ ' + response.data.data.message)
          unlinkFn()
          postRelease(response.data.data.module.id, communityId)
        }).catch(function (response) {
          spinner(response.response.data.error || 'Network error')
          unlinkFn()
          process.exit(1)
        })
      })
    })
  })
}

module.exports = function (domain) {
  API.checkSignedIn()

  API.get('/communities/' + encodeURIComponent(domain)).then(function (response) {
    // Community already exists
    deployWithCommunity(response.data.data.id)
  }).catch(function () {
    // Community does not exist yet

    // TODO: ask what org to use to create the community if the user is member of more than one org.
    // output.warn('Community with domain ' + domain + ' does not yet exist.')

    // Create community
    const stopSpinner = output.wait('Creating new community ' + domain)
    API.post('/communities', { domain: domain }).then(function (response) {
      stopSpinner(true)
      deployWithCommunity(response.data.data.id)
    }).catch(function (err) {
      output.err(err)
    })
  })
}

==> includable-1.18.0.tgz: package/lib/commands/modules/deploy.js <==
/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

const FormData = require('form-data')
const fs = require('fs')
const axios = require('axios')
const chalk = require('chalk')

const API = require('../../util/API')
const output = require('../../output')
const runHelpers = require('../../run-helpers')
const Module = require('../../containers/Module')

const postRelease = function (moduleId, communityId) {
  const spinner = output.wait('Linking module to community')
  API.post('/communities/' + communityId + '/modules', { module: moduleId }).then(function () {
    spinner(true)
    output.newline()
    output.success('Done! Only thing left is to configure your DNS records:')
    output.write('\n' + chalk.bold.magenta('  CNAME inc-dns.com') + chalk.gray(' for any subdomains, or\n'))
    output.write(chalk.bold.magenta('  A 79.125.7.166') + chalk.gray(' if you can\'t add a CNAME record\n\n\n'))
  })
}

const deployWithCommunity = function (communityId) {
  Module.getManifest(function (manifest) {
    if (!('name' in manifest) || !manifest.name || typeof manifest.name !== 'string' || !manifest.name.length) {
      output.err('Please set a valid value for key `name` in module.json')
      process.exit(1)
    }

    runHelpers.startChildProcess('build', function (error, exitCode) {
      if (error || exitCode > 0) {
        output.err('Build script exited with non-zero exit code, cancelling publish action')
        process.exit(1)
      }
      runHelpers.createZipArchive('.', 'Publish', function (zipFile, size, unlinkFn) {
        const spinner = output.wait(runHelpers.logSyncMessage('Uploading and building module (' + size + ')', true))

        const data = new FormData(null)
        data.append('file', fs.createReadStream(zipFile))
        axios.post('https://monkey.internal.includable.com/upload', data, { headers: data.getHeaders() })
          .then(function (response) {
            spinner(true)
            const spinner2 = output.wait(runHelpers.logSyncMessage('Creating deployment', true))
            API.post('/modules/publish', { registry_id: response.data.id })
              .then(function (response) {
                setTimeout(function () {
                  spinner2(true)
                  postRelease(response.data.data.module.id, communityId)
                }, 5000)
                unlinkFn()
              })
              .catch(function (response) {
                spinner2(response.response.data.error || 'Network error')
                unlinkFn()
                process.exit(1)
              })
          })
          .catch(function (response) {
            spinner(response.response.data.error || 'Network error')
            unlinkFn()
            process.exit(1)
          })
      })
    })
  })
}

module.exports = function (domain) {
  API.checkSignedIn()

  API.get('/communities/' + encodeURIComponent(domain)).then(function (response) {
    // Community already exists
    deployWithCommunity(response.data.data.id)
  }).catch(function () {
    // Community does not exist yet

    // TODO: ask what org to use to create the community if the user is member of more than one org.
    // output.warn('Community with domain ' + domain + ' does not yet exist.')

    // Create community
    const stopSpinner = output.wait('Creating new community ' + domain)
    API.post('/communities', { domain: domain }).then(function (response) {
      stopSpinner(true)
      deployWithCommunity(response.data.data.id)
    }).catch(function (err) {
      output.err(err)
    })
  })
}
